pub fn group_commitment(commitment_list: &[(Scalar, PublicNonce)]) -> ScalarExpand description
Compute the group commitment from the list of PartyIDs and nonce commitments using XMD-based expansion.
pub fn group_commitment(commitment_list: &[(Scalar, PublicNonce)]) -> ScalarCompute the group commitment from the list of PartyIDs and nonce commitments using XMD-based expansion.