pub fn group_commitment_compressed(
commitment_list: &[(Scalar, Compressed, Compressed)],
) -> ScalarExpand description
Compute the group commitment from the list of PartyIDs and nonce commitments using XMD-based expansion.
pub fn group_commitment_compressed(
commitment_list: &[(Scalar, Compressed, Compressed)],
) -> ScalarCompute the group commitment from the list of PartyIDs and nonce commitments using XMD-based expansion.