pub fn intermediate(
msg: &[u8],
party_ids: &[u32],
nonces: &[PublicNonce],
) -> (Vec<Point>, Point)Expand description
Compute the intermediate values used in both the parties and the aggregator
pub fn intermediate(
msg: &[u8],
party_ids: &[u32],
nonces: &[PublicNonce],
) -> (Vec<Point>, Point)Compute the intermediate values used in both the parties and the aggregator