pub fn tweaked_public_key_from_tweak(public_key: &Point, tweak: Scalar) -> PointExpand description
Create a BIP341 compliant taproot tweak from a public key and a pre-calculated tweak
We should never trigger the unwrap here, because Point::lift_x only returns an error when the x-coordinate is not on the secp256k1 curve, but we know that public_key.x() is on the curve because it is a Point.